@@ -5,7 +5,7 @@ from .views import ASNViewSet, BGPSessionViewSet, RoutingPolicyViewSet
 router = routers.DefaultRouter()
 router.register('asn', ASNViewSet)
 router.register('session', BGPSessionViewSet),
-router.register('routing_policy', RoutingPolicyViewSet)
+router.register('routing-policy', RoutingPolicyViewSet)
 
 
 urlpatterns = router.urls
