@@ -39,11 +39,11 @@ urlpatterns = [
     path('session/<int:pk>/delete/', BGPSessionDeleteView.as_view(), name='session_delete'),
     path('session/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='session_changelog', kwargs={'model': BGPSession}),
     # Routing Policies
-    path('routing_policy/<int:pk>/', RoutingPolicyView.as_view(), name='routing_policy'),
-    path('routing_policy/', RoutingPolicyListView.as_view(), name='routing_policy_list'),
-    path('routing_policy/add/', RoutingPolicyEditView.as_view(), name='routing_policy_add'),
-    path('routing_policy/<int:pk>/edit/', RoutingPolicyEditView.as_view(), name='routing_policy_edit'),
-    path('routing_policy/delete/', RoutingPolicyBulkDeleteView.as_view(), name='routing_policy_bulk_delete'),
-    path('routing_policy/<int:pk>/delete/', RoutingPolicyDeleteView.as_view(), name='routing_policy_delete'),
-    path('routing_policy/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='routing_policy_changelog', kwargs={'model': RoutingPolicy}),
+    path('routing-policy/<int:pk>/', RoutingPolicyView.as_view(), name='routing_policy'),
+    path('routing-policy/', RoutingPolicyListView.as_view(), name='routing_policy_list'),
+    path('routing-policy/add/', RoutingPolicyEditView.as_view(), name='routing_policy_add'),
+    path('routing-policy/<int:pk>/edit/', RoutingPolicyEditView.as_view(), name='routing_policy_edit'),
+    path('routing-policy/delete/', RoutingPolicyBulkDeleteView.as_view(), name='routing_policy_bulk_delete'),
+    path('routing-policy/<int:pk>/delete/', RoutingPolicyDeleteView.as_view(), name='routing_policy_delete'),
+    path('routing-policy/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='routing_policy_changelog', kwargs={'model': RoutingPolicy}),
 ]
